import{L as t}from"./lottie.61602e49.js";import{d as a,r as d,o as r,b as s,c as i,y as c,D as _,t as f}from"./registerWidgets.2f354556.js";(function(){try{var n=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(n._sentryDebugIds=n._sentryDebugIds||{},n._sentryDebugIds[e]="54c032db-c071-45dd-a5b5-5cfd0e6f53f1",n._sentryDebugIdIdentifier="sentry-dbid-54c032db-c071-45dd-a5b5-5cfd0e6f53f1")}catch{}})();const l={class:"container"},u=a({__name:"LoadingIndicator",setup(n){const e=d(null);return r(()=>{!e.value||t.loadAnimation({container:e.value,renderer:"svg",loop:!0,autoplay:!0,path:"/circularLoading.json"})}),(o,p)=>(s(),i("div",l,[c("div",{ref_key:"animation",ref:e,class:"animation"},null,512),_(o.$slots,"default",{},void 0,!0)]))}});const g=f(u,[["__scopeId","data-v-c30401d8"]]);export{g as L};
//# sourceMappingURL=LoadingIndicator.14779776.js.map
