import{_ as k}from"./logo.084e5d7c.js";import{t as i,b as o,c as t,Q as u,R as p,y as a,d as b,J as I,a as $,A as _,O as g,e as r,x as m,V as f,F as w,N as x,E as L,aq as N}from"./registerWidgets.2f354556.js";import{p as l}from"./passwordlessManager.96ab3f5a.js";import{a as C}from"./asyncComputed.7c1b85ba.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},s=new Error().stack;s&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[s]="3ff677b9-3261-41b5-9681-aeaaab29772b",e._sentryDebugIdIdentifier="sentry-dbid-3ff677b9-3261-41b5-9681-aeaaab29772b")}catch{}})();const B={},v=e=>(u("data-v-439be421"),e=e(),p(),e),D={class:"logo"},S=v(()=>a("img",{class:"logo-img",src:k,alt:"Abstra cloud logo"},null,-1)),V=v(()=>a("span",null,"Abstra Cloud",-1)),A=[S,V];function E(e,s){return o(),t("div",D,A)}const R=i(B,[["render",E],["__scopeId","data-v-439be421"]]),F={key:0},U={key:1,class:"logged"},q={class:"author-email"},J={key:2},M=b({__name:"LoginBlock",setup(e){const s=I(),{result:n,loading:c,refetch:d}=C(async()=>l.getUser());function h(){l.removeUser(),d(),s.push({name:"login"})}return(P,W)=>{const y=$("router-link");return _(c)?(o(),t("div",F,"loading...")):_(n)?(o(),t("div",U,[a("span",q,g(_(n).claims.email),1),a("button",{class:"btn",onClick:h},"Logout")])):(o(),t("div",J,[r(y,{class:"btn",to:"/login"},{default:m(()=>[f("Login")]),_:1})]))}}});const O=i(M,[["__scopeId","data-v-6c08207b"]]),Q=e=>(u("data-v-7bfa390c"),e=e(),p(),e),T={class:"nav"},j={class:"left"},z={key:0,class:"breadcrumb-container"},G=Q(()=>a("span",{class:"divider"},">",-1)),H={class:"right"},K=b({__name:"Navbar",props:{breadcrumb:{}},setup(e){return(s,n)=>(o(),t("nav",T,[a("div",j,[r(R),s.breadcrumb?(o(),t("div",z,[(o(!0),t(w,null,x(s.breadcrumb,(c,d)=>(o(),t("span",{key:d,class:"breadcrumb-item"},[r(_(N),{class:"breadcrumb-link",to:c.path},{default:m(()=>[f(g(c.label),1)]),_:2},1032,["to"]),G]))),128))])):L("",!0)]),a("div",H,[r(O)])]))}});const se=i(K,[["__scopeId","data-v-7bfa390c"]]);export{se as N};
//# sourceMappingURL=Navbar.7c7b2337.js.map
