import{P as r}from"./Passwordless.1cb3171a.js";import{d as a,J as d,b as i,c,e as s,x as f,t as _}from"./registerWidgets.2f354556.js";import{M as m}from"./member.1ef4bf03.js";import{W as p}from"./WidgetsFrame.ade6550a.js";import"./CircularLoading.f70f248e.js";import"./lottie.61602e49.js";import"./icons.1cdfa11b.js";import"./passwordlessManager.96ab3f5a.js";import"./pubsub.cb65003c.js";import"./gateway.b2e13b61.js";import"./activeRecord.931023a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="decfe0a3-c38f-4d59-836d-f85350602793",e._sentryDebugIdIdentifier="sentry-dbid-decfe0a3-c38f-4d59-836d-f85350602793")}catch{}})();const l={class:"login"},u=a({__name:"Login",setup(e){const o=d();async function t(n){await m.login(),o.push({name:"home"})}return(n,g)=>(i(),c("div",l,[s(p,{theme:"white","main-color":"#d14056","font-family":"sans-serif",runtime:"dash"},{default:f(()=>[s(r,{class:"passwordless",onDone:t})]),_:1})]))}});const B=_(u,[["__scopeId","data-v-0e3dc783"]]);export{B as default};
//# sourceMappingURL=Login.0e7bf107.js.map
