import{u as s}from"./icons.1cdfa11b.js";import{d as r,a as c,b as d,c as i,e as _,A as f,V as l,t as u}from"./registerWidgets.2f354556.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="9d6eb719-7771-42a0-b646-ba0f880fb7fd",e._sentryDebugIdIdentifier="sentry-dbid-9d6eb719-7771-42a0-b646-ba0f880fb7fd")}catch{}})();const b=r({__name:"BackButton",emits:["exitFullscreenPreview"],setup(e,{emit:t}){return(o,n)=>{const a=c("icon");return d(),i("button",{class:"back-btn",onClick:n[0]||(n[0]=p=>t("exitFullscreenPreview"))},[_(a,{class:"icon",path:f(s),width:"20",height:"20",fill:"#5A677A"},null,8,["path"]),l(" Editor ")])}}});const w=u(b,[["__scopeId","data-v-eaeb3a6e"]]);export{w as B};
//# sourceMappingURL=BackButton.d3af3b6e.js.map
