import{D as b,_ as g}from"./DropdownMenu.f3f9574e.js";import{L as w}from"./CircularLoading.f70f248e.js";import{d as I,a as B,b as e,u as p,c as o,y as s,O as n,D,F as u,N as _,E as C,H as f,x as L,V as S,Q as T,R,t as N}from"./registerWidgets.2f354556.js";(function(){try{var a=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},l=new Error().stack;l&&(a._sentryDebugIds=a._sentryDebugIds||{},a._sentryDebugIds[l]="5912004a-1f32-4840-9c56-d90c2df412ed",a._sentryDebugIdIdentifier="sentry-dbid-5912004a-1f32-4840-9c56-d90c2df412ed")}catch{}})();const h=a=>(T("data-v-a0aa59f6"),a=a(),R(),a),V={key:1,class:"runtimes-container"},E={class:"header"},U={class:"title-wrapper"},x={class:"description"},F={key:0,class:"empty-list"},j=h(()=>s("img",{src:g},null,-1)),z={class:"empty-list-title"},A={class:"empty-list-description"},H={key:1},M={key:2},O={key:2,class:"video-section"},Q=h(()=>s("h1",null,"See it in action",-1)),$=["src"],q=I({__name:"RuntimeList",props:{loading:{type:Boolean},title:{},description:{},createButtonText:{},emptyTitle:{},videoUrl:{},table:{}},emits:["create"],setup(a,{emit:l}){async function d(){l("create")}return(t,G)=>{const k=B("router-link");return t.loading?(e(),p(w,{key:0,class:"loading-wrapper",justify:"center"})):(e(),o("div",V,[s("div",E,[s("div",U,[s("h1",null,n(t.title),1),s("p",x,n(t.description),1),s("button",{onClick:d},n(t.createButtonText),1)])]),t.table.rows.length===0?(e(),o("div",F,[j,s("div",z,n(t.emptyTitle),1),s("div",A,[D(t.$slots,"empty-description",{},void 0,!0)]),s("button",{onClick:d},n(t.createButtonText),1)])):(e(),o("table",H,[s("thead",null,[(e(!0),o(u,null,_(t.table.columns,(r,c)=>(e(),o("td",{key:c,class:"cell"},n(r.name),1))),128))]),(e(!0),o(u,null,_(t.table.rows,(r,c)=>{var m;return e(),o("tr",{key:c,class:f((m=r.classes)!=null?m:[])},[(e(!0),o(u,null,_(r.cells,(i,v)=>{var y;return e(),o("td",{key:v,class:f((y=i.classes)!=null?y:[])},[i.actions?(e(),p(b,{key:0,title:"Actions","highlight-last":!0,options:i.actions,payload:{key:r.key}},null,8,["options","payload"])):i.link?(e(),p(k,{key:1,to:i.link,class:"runtime-title"},{default:L(()=>[S(n(i.text),1)]),_:2},1032,["to"])):(e(),o("div",M,n(i.text),1))],2)}),128))],2)}),128))])),t.videoUrl?(e(),o("section",O,[Q,s("iframe",{class:"runtimes-example-video",src:t.videoUrl,title:"runtimes example",frameborder:"0",allow:"accelerometer; autoplay; clipboard-write; encrypted-media; gyroscope; picture-in-picture; web-share",allowfullscreen:""},null,8,$)])):C("",!0)]))}}});const W=N(q,[["__scopeId","data-v-a0aa59f6"]]);export{W as R};
//# sourceMappingURL=RuntimeList.d806a58a.js.map
