import{S as f,L as t}from"./registerWidgets.2f354556.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},e=new Error().stack;e&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[e]="01587050-a687-47fa-9abe-ec25f39fe3ba",r._sentryDebugIdIdentifier="sentry-dbid-01587050-a687-47fa-9abe-ec25f39fe3ba")}catch{}})();const i=r=>{const e=f({loading:!0,result:null,error:null}),n=l=>(e.value={loading:!1,result:l,error:null},l),a=l=>{e.value={loading:!1,result:null,error:l}},o=()=>{e.value={loading:!0,result:null,error:null},r().then(n).catch(a)};o();const s=t(()=>e.value.loading),u=t(()=>e.value.result),d=t(()=>e.value.error);return{loading:s,result:u,error:d,refetch:o}};export{i as a};
//# sourceMappingURL=asyncComputed.7c1b85ba.js.map
