import{d as u,K as f,L as b,b as y,u as g,A as _}from"./registerWidgets.2f354556.js";import{a as w}from"./asyncComputed.7c1b85ba.js";import"./gateway.b2e13b61.js";import{M as s}from"./member.1ef4bf03.js";import"./index.a8dd38cc.js";import{C as I}from"./CrudView.f76acddd.js";import"./passwordlessManager.96ab3f5a.js";import"./pubsub.cb65003c.js";import"./activeRecord.931023a0.js";import"./DropdownMenu.f3f9574e.js";import"./Modal.55b06151.js";import"./LoadingIndicator.14779776.js";import"./lottie.61602e49.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="98b54015-75f5-45ef-9ba5-f5948c56d516",e._sentryDebugIdIdentifier="sentry-dbid-98b54015-75f5-45ef-9ba5-f5948c56d516")}catch{}})();const K=u({__name:"Members",setup(e){const a=f().params.organizationId,i=[{key:"email",label:"Email"}],m=async t=>{await s.create(a,t.email),c()},{loading:l,result:d,refetch:c}=w(()=>s.list(a)),p=b(()=>{var t,r;return{columns:[{name:"Email"},{name:"Role"}],rows:(r=(t=d.value)==null?void 0:t.map(n=>({key:n.email,cells:[{text:n.email,classes:["title","centered"]},{text:n.role,classes:["centered"]}]})))!=null?r:[]}});return(t,r)=>(y(),g(I,{"entity-name":"members",loading:_(l),title:"Organization members",description:"List all organization members.","empty-title":"No members yet",table:p.value,"create-button-text":"Add members",fields:i,onCreate:m},null,8,["loading","table"]))}});export{K as default};
//# sourceMappingURL=Members.f2b0dd28.js.map
