import{S as c}from"./Sidebar.c2e319e7.js";import{N as d}from"./Navbar.7c7b2337.js";import{C as m,D as p,E as l}from"./icons.1cdfa11b.js";import{d as u,K as _,L as b,a as g,b as f,c as v,e as t,y,F as z,t as h}from"./registerWidgets.2f354556.js";import{a as w}from"./asyncComputed.7c1b85ba.js";import"./gateway.b2e13b61.js";import{O as I}from"./organization.00ab1f23.js";import"./index.a8dd38cc.js";import"./Tooltip.38335a1d.js";import"./logo.084e5d7c.js";import"./passwordlessManager.96ab3f5a.js";import"./pubsub.cb65003c.js";import"./activeRecord.931023a0.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="3ca3c481-012c-4b76-93ab-d7f1de71c383",e._sentryDebugIdIdentifier="sentry-dbid-3ca3c481-012c-4b76-93ab-d7f1de71c383")}catch{}})();const O={class:"organization"},D=u({__name:"Organization",setup(e){const n=_().params.organizationId,{result:o}=w(()=>I.get(n)),r=b(()=>o.value?[{label:"My organizations",path:"/organizations"},{label:o.value.name,path:`/organizations/${o.value.id}`}]:void 0),i=[{name:"Organization",items:[{name:"Projects",icon:m,path:"projects"},{name:"Members",icon:p,path:"members"},{name:"Billing",icon:l,path:"billing",unavailable:!0}]}];return(k,x)=>{const s=g("router-view");return f(),v(z,null,[t(d,{breadcrumb:r.value},null,8,["breadcrumb"]),y("div",O,[t(c,{class:"sidebar",sections:i}),t(s)])],64)}}});const $=h(D,[["__scopeId","data-v-51ce7239"]]);export{$ as default};
//# sourceMappingURL=Organization.a7c67b5b.js.map
