import{d as u,K as b,L as p,a as g,b as _,c as f,e as s,y as l,F as v,t as y}from"./registerWidgets.2f354556.js";import{a as h}from"./asyncComputed.7c1b85ba.js";import{P as j}from"./project.3182f929.js";import"./gateway.b2e13b61.js";import{O as z}from"./organization.00ab1f23.js";import"./index.a8dd38cc.js";import{N as I}from"./Navbar.7c7b2337.js";import{S as w}from"./Sidebar.c2e319e7.js";import{F as P,G as k,H as x,I as B,J as C,K as D,C as $,D as E,E as M}from"./icons.1cdfa11b.js";import"./activeRecord.931023a0.js";import"./pubsub.cb65003c.js";import"./passwordlessManager.96ab3f5a.js";import"./logo.084e5d7c.js";import"./Tooltip.38335a1d.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="a2dd8a09-5d28-4b6f-9efa-8315e46f2c98",o._sentryDebugIdIdentifier="sentry-dbid-a2dd8a09-5d28-4b6f-9efa-8315e46f2c98")}catch{}})();const N={class:"project"},S={class:"content-wrapper"},F=u({__name:"Project",setup(o){const i=b().params.projectId,{result:e}=h(()=>j.get(i).then(async a=>{const t=await z.get(a.organizationId);return{project:a,organization:t}})),d=p(()=>{var a,t,n,c;return((a=e.value)==null?void 0:a.organization)&&e.value.project?[{label:"My organizations",path:"/organizations"},{label:(n=(t=e.value)==null?void 0:t.organization)==null?void 0:n.name,path:`/organizations/${(c=e.value)==null?void 0:c.organization.id}`},{label:e.value.project.name,path:`/projects/${e.value.project.id}`}]:void 0}),m=p(()=>{var a;return(a=e.value)!=null&&a.project?[{name:"Project",items:[{name:"Builds",path:"builds",icon:P},{name:"Connectors",path:"connectors",icon:k},{name:"API Keys",path:"api-keys",icon:x},{name:"Env Vars",path:"env-vars",icon:B},{name:"Logs",icon:C,path:"logs",beta:!0},{name:"Settings",icon:D,path:"settings"}]},{name:"Organization",items:[{name:"Projects",icon:$,path:`/organizations/${e.value.project.organizationId}/projects`},{name:"Members",icon:E,path:`/organizations/${e.value.project.organizationId}/members`},{name:"Billing",icon:M,path:`/organizations/${e.value.project.organizationId}/billing`,unavailable:!0}]}]:[]});return(a,t)=>{const n=g("router-view");return _(),f(v,null,[s(I,{class:"nav",breadcrumb:d.value},null,8,["breadcrumb"]),l("div",N,[s(w,{class:"sidebar",sections:m.value},null,8,["sections"]),l("div",S,[s(n)])])],64)}}});const X=y(F,[["__scopeId","data-v-4f3bb041"]]);export{X as default};
//# sourceMappingURL=Project.d9aafa9b.js.map
