import{d as p,K as u,L as m,b as f,u as _,x as b,A as y,Q as g,R as w,y as i,V as n,t as h}from"./registerWidgets.2f354556.js";import{a as x}from"./asyncComputed.7c1b85ba.js";import"./gateway.b2e13b61.js";import{B as I}from"./build.81f5839b.js";import"./index.a8dd38cc.js";import{C as v}from"./CrudView.f76acddd.js";import{J as B,L as D}from"./icons.1cdfa11b.js";import{r as C}from"./console.3e7b332e.js";import{f as k}from"./index.b048d0fb.js";import"./passwordlessManager.96ab3f5a.js";import"./pubsub.cb65003c.js";import"./activeRecord.931023a0.js";import"./DropdownMenu.f3f9574e.js";import"./Modal.55b06151.js";import"./LoadingIndicator.14779776.js";import"./lottie.61602e49.js";import"./index.afe47008.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="46fd3cec-0839-4939-a7a8-dbab512ab741",e._sentryDebugIdIdentifier="sentry-dbid-46fd3cec-0839-4939-a7a8-dbab512ab741")}catch{}})();const S=e=>(g("data-v-e61ab2b9"),e=e(),w(),e),V=S(()=>i("div",{class:"instructions"},[n(" Get started with the local editor in seconds: "),i("pre",null,`    $ pip install abstra --upgrade
    $ abstra serve ./your-project-directory
    `),n(" And you're done! Explore the local editor and start building apps. ")],-1)),A=p({__name:"Builds",setup(e){const a=u().params.projectId,{loading:d,result:c}=x(()=>I.list(a)),l=m(()=>{var s,r;return{columns:[{name:"Id"},{name:"Date"},{name:"Status"},{name:"Actions"}],rows:(r=(s=c.value)==null?void 0:s.map(t=>({key:t.id,cells:[{text:t.id.slice(0,8),classes:["centered"]},{text:k(t.createdAt,Date.now(),{addSuffix:!0}),classes:[]},{text:t.status+(t.log?": "+t.log:""),classes:[]},{text:"",classes:["centered"],actions:[{icon:B,label:"View logs",onClick:()=>C.push({name:"logs",params:{projectId:a},query:{buildId:t.id}})},{icon:D,label:"Download files",onClick:()=>t.download()}]}]})))!=null?r:[]}});return(s,r)=>(f(),_(v,{"entity-name":"build",loading:y(d),title:"Builds",description:"Each build is a version of your app. You can create a new build by deploying your app from the local editor.","empty-title":"No builds here yet",table:l.value},{"empty-description":b(()=>[V]),_:1},8,["loading","table"]))}});const O=h(A,[["__scopeId","data-v-e61ab2b9"]]);export{O as default};
//# sourceMappingURL=Builds.9b09777c.js.map
