import{t as o,a as r,b as i,u as c,f as p,g as d,_,h as u,k as f,T as l,P as h,C as b,M as g,s as y,i as m,j as s,l as v,m as w,n as k}from"./registerWidgets.2f354556.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="977fe3a1-ffb9-4498-b0b3-3fd52caaa798",e._sentryDebugIdIdentifier="sentry-dbid-977fe3a1-ffb9-4498-b0b3-3fd52caaa798")}catch{}})();const I={};function A(e,t){const n=r("router-view");return i(),c(n,{style:{"min-height":"100vh","box-sizing":"border-box",width:"100%"}})}const x=o(I,[["render",A]]),a=p({history:d("/"),routes:[{path:"/:path(.*)*",name:"player",component:()=>_(()=>import("./Player.f37427c3.js"),["assets/Player.f37427c3.js","assets/index.afe47008.js","assets/registerWidgets.2f354556.js","assets/registerWidgets.eb368e85.css","assets/uuid.9b12df3f.js","assets/broker.8b121cd9.js","assets/passwordlessManager.96ab3f5a.js","assets/pubsub.cb65003c.js","assets/Passwordless.1cb3171a.js","assets/CircularLoading.f70f248e.js","assets/lottie.61602e49.js","assets/CircularLoading.f81b57b4.css","assets/icons.1cdfa11b.js","assets/Passwordless.86ac0c56.css","assets/executeJs.27fe2afb.js","assets/PlayerNavbar.bedaf2b3.js","assets/PlayerNavbar.76a7eb2f.css","assets/Steps.74e2104a.js","assets/Steps.998aa76d.css","assets/Modal.55b06151.js","assets/Modal.5aaf8eba.css","assets/executeJs.887e9a58.css","assets/WidgetsFrame.ade6550a.js","assets/WidgetsFrame.0816a5f5.css","assets/ActionButton.vue_vue_type_script_setup_true_lang.ab6c6d5f.js","assets/broker.2e000de9.css","assets/DashPlayer.813c0f29.js","assets/DashPlayer.4868beea.css","assets/asyncComputed.7c1b85ba.js","assets/Player.77337a17.css"])}],scrollBehavior(e){if(e.hash)return{el:e.hash}}});class D{static init(){setInterval(()=>fetch("/_healthcheck"),20*1e3)}}const W=()=>{const e=u({render:()=>f(x)});l.init(),D.init(),e.use(a),e.use(h),e.mount("#app"),e.component("VSelect",b),e.component("Markdown",g),e.component("Message",y),m(e,a),s(e,v),s(e,w),s(e,k)};W();
//# sourceMappingURL=player.0dd3e055.js.map
